==> haskell-text-binary-0.2.1.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-binary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-binary
version: 0.2.1.1
id: text-binary-0.2.1.1-Ixe45FI2fTB8kwbVqDai0g
key: text-binary-0.2.1.1-Ixe45FI2fTB8kwbVqDai0g
license: BSD2
maintainer: waszczuk.kuba@gmail.com
stability: provisional
homepage: https://github.com/kawu/text-binary
synopsis: Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.
category: Data
author: Jakub Waszczuk
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Binary
abi: ee2dbfef3dba2fde6b3f88fdceed35a6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-binary-0.2.1.1
hs-libraries: HStext-binary-0.2.1.1-Ixe45FI2fTB8kwbVqDai0g
depends:
    base-4.10.1.0 binary-0.8.5.1 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html: /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-binary-0.2.1.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-binary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-binary
version: 0.2.1.1
id: text-binary-0.2.1.1-11KcjRXxiXrFu9GEPeBOb8
key: text-binary-0.2.1.1-11KcjRXxiXrFu9GEPeBOb8
license: BSD2
maintainer: waszczuk.kuba@gmail.com
stability: provisional
homepage: https://github.com/kawu/text-binary
synopsis: Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.
category: Data
author: Jakub Waszczuk
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Binary
abi: 76544165555bc82cd348623c7f212024
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-binary-0.2.1.1
hs-libraries: HStext-binary-0.2.1.1-11KcjRXxiXrFu9GEPeBOb8
depends:
    base-4.10.1.0 binary-0.8.5.1 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html: /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
